require 'httparty'

class XeroAPI

  XERO_CONNECTOR_URL = 'http://xero.accountdock.com'

  def initialize(xero_guid)
    @xero_guid = xero_guid
  end

  def accounts(type = nil)
    return cached_accounts if type.nil?
    cached_accounts.find_all { |account| account.type == type }
  rescue StandardError # Handles unauthorized case
    []
  end

  def new_transaction(transaction_data)
    post('/transactions/new', data: transaction_data)
  end

  def new_invoice(invoice_data)
    post('/invoices/new', data: invoice_data)
  end

  def new_transfer(transfer_data)
    post('/transfers/new', data: transfer_data)
  end

  def balance(bank_name)
    get('/balance', { bank_name: bank_name }).body
  end

  private

  attr_reader :xero_guid

  def cached_accounts
    @cached_accounts ||= get('/accounts/').map do |account_hash|
      OpenStruct.new(account_hash)
    end
  end

  def post(path, body)
    HTTParty.post(
      request_url(path),
      body: body.merge(xero_guid: xero_guid).to_json,
      headers: { 'Content-Type' => 'application/json' }
    )
  end

  def get(path, query = {})
    HTTParty.get(
      request_url(path),
      query: query.merge(guid: xero_guid)
    )
  end

  def request_url(path)
    XERO_CONNECTOR_URL + path
  end
end
