module XeroCLI
  class Commands
    attr_reader :options, :xero

    def initialize(options, xero)
      @options = options
      @xero = xero
    end

    def perform
      help          if options.help
      set_guid      if options.set_guid
      show_guid     if options.show_guid
      show_accounts if options.show_accounts
      get_guid      if options.get_guid
      spend         if options.spend
      receive       if options.receive
      transfer      if options.transfer
      balance       if options.balance
      default
    end

    private

    def help
      puts xero
      exit 1
    end

    def set_guid
      XeroCLI::Credentials.set(options.set_guid)
      ap "Xero GUID set to #{read_guid}"
      exit 1
    end

    def show_guid
      ap read_guid
      exit 1
    end

    def get_guid
      system('start', XeroCLI::Constants::XERO_CONNECTOR_ADDRESS)
      system('xdg-open', XeroCLI::Constants::XERO_CONNECTOR_ADDRESS)
      system('open', XeroCLI::Constants::XERO_CONNECTOR_ADDRESS)
      exit 1
    end

    def show_accounts
      accounts = XeroCLI::Commands::Accounts.new(options)
      accounts.perform
      exit 1
    end

    def spend
      spend = XeroCLI::Commands::Spend.new(options)
      spend.perform
      exit 1
    end

    def receive
      receive = XeroCLI::Commands::Receive.new(options)
      receive.perform
      exit 1
    end

    def transfer
      transfer = XeroCLI::Commands::Transfer.new(options)
      transfer.perform
      exit 1
    end

    def balance
      balance = XeroCLI::Commands::Balance.new(options)
      balance.perform
      exit 1
    end

    def default
      puts 'Please use "xero -h" or "xero --help" to check the available commands.'
    end

    def read_guid
      @read_guid ||= XeroCLI::Credentials.read_guid
    end

    def get_account(type)
      xero_api.accounts(type)
    end
  end
end
