class XeroCLI::Commands::Receive < XeroCLI::Commands::Base
  TRANSACTION_TYPE = 'RECEIVE'.freeze

  def initialize(options)
    @receive = options.receive.to_f
    @to = options.to
    @from = options.from
    @on = options.on
    @as = options.as
  end

  def perform
    check_exceptions
    account_code = as.nil? ? nil : XeroCLI::AccountsStorage.find_account_code_by_name(as)
    transaction_attributes = XeroCLI::Templates::Transaction.attributes(receive, TRANSACTION_TYPE, from, to, account_code, on)
    create_transaction(transaction_attributes)
    write_to_terminal
  end

  private

  attr_reader :receive, :to, :from, :on, :as

  def check_exceptions
    raise Exception, 'Amount should positive' if receive.negative? || receive.zero?
    raise Exception, 'Please add "--from NAME"' if from.nil?
  end

  def write_to_terminal
    output = ["Received #{receive}"]
    output << "from #{from}"
    output << "to #{to || XeroCLI::Constants::STRIPE_BANK_NAME}"
    output << "as #{as}" if as
    output << "on #{format_date(on)}" if on
    ap output.join(' ')
  end

  def create_transaction(json)
    xero_api.new_transaction(json)
  end
end
