class XeroCLI::Commands::Spend < XeroCLI::Commands::Base
  TRANSACTION_TYPE = 'SPEND'.freeze

  def initialize(options)
    @spend = options.spend.to_f
    @to = options.to
    @from = options.from
    @on = options.on
    @as = options.as
  end

  def perform
    check_exceptions
    account_code = as.nil? ? nil : XeroCLI::AccountsStorage.find_account_code_by_name(as)
    transaction_attributes = XeroCLI::Templates::Transaction.attributes(spend, TRANSACTION_TYPE, to, from, account_code, on)
    create_transaction(transaction_attributes)
    write_to_terminal
  end

  private

  attr_reader :spend, :to, :from, :on, :as

  def check_exceptions
    raise Exception, 'Amount should positive' if spend.negative? || spend.zero?
    raise Exception, 'Please add "--to NAME"' if to.nil?
  end

  def write_to_terminal
    output = ["Spent #{spend}"]
    output << "from #{from || XeroCLI::Constants::STRIPE_BANK_NAME}"
    output << "to #{to}"
    output << "as #{as}" if as
    output << "on #{format_date(on)}" if on
    ap output.join(' ')
  end

  def create_transaction(json)
    xero_api.new_transaction(json)
  end
end
