class XeroCLI::Commands::Transfer < XeroCLI::Commands::Base
  TRANSACTION_TYPE = 'RECEIVE'.freeze

  def initialize(options)
    @transfer = options.transfer.to_f
    @to = options.to
    @from = options.from
    @on = options.on
  end

  def perform
    check_exceptions
    transfer_attributes = XeroCLI::Templates::Transfer.attributes(transfer, from, to, on)
    create_transfer(transfer_attributes)
    write_to_terminal
  end

  private

  attr_reader :transfer, :to, :from, :on

  def check_exceptions
    raise Exception, 'Amount should positive' if transfer.negative? || transfer.zero?
    raise Exception, 'Please add "--from NAME"' if from.nil?
    raise Exception, 'Please add "--to NAME"' if to.nil?
  end

  def write_to_terminal
    output = ["Transfer #{transfer}"]
    output << "from #{from}"
    output << "to #{to}"
    output << "on #{format_date(on)}" if on
    ap output.join(' ')
  end

  def create_transfer(json)
    xero_api.new_transfer(json)
  end
end
